# RelatiPy 🌀

Herramienta simbólica, numérica y visual para explorar la geometría y dinámica generada por diferentes métricas, en particular enfocado en **agujeros negros de Kerr**.  

---

## 📑 Tabla de contenidos
- [RelatiPy 🌀](#relatipy-)
  - [📑 Tabla de contenidos](#-tabla-de-contenidos)
  - [🌌 Introducción](#-introducción)
  - [🏗️ Arquitectura del proyecto](#️-arquitectura-del-proyecto)
  - [Inicializar proyecto](#inicializar-proyecto)

---

## 🌌 Introducción
RelatiPy tiene como objetivo brindar un entorno unificado para estudiar métricas en general, aunque se enfoca principalmente en **agujeros negros de Kerr**, combinando:
- **Cálculos simbólicos** (tensores, invariantes, geodésicas).
- **Simulaciones numéricas** (órbitas, trayectorias de partículas y fotones).
- **Visualización interactiva** (potenciales efectivos, mapas de curvatura, trayectorias).  

Este proyecto busca servir como herramienta de **investigación**.

---

## 🏗️ Arquitectura del proyecto
El proyecto se organiza en módulos separados:
```
/src/
  /symbolic      → cálculos simbólicos
  /numeric       → cálculos numéricos
  /visualization → visualización y análisis interactivo
/docs          → documentación teórica y notas
```

## Inicializar proyecto
Aun no implementado 